==> apache-ambari-2.6.2-src.tar.gz: apache-ambari-2.6.2-src/contrib/views/files/src/main/resources/ui/app/models/file.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import DS from 'ember-data';
import Ember from 'ember';

export default DS.Model.extend({

  isDirectory                       : DS.attr('boolean'),
  readAccess                        : DS.attr('boolean'),
  writeAccess                       : DS.attr('boolean'),
  executeAccess                     : DS.attr('boolean'),
  len                               : DS.attr('number'),
  owner                             : DS.attr('string'),
  group                             : DS.attr('string'),
  permission                        : DS.attr('string'),
  accessTime                        : DS.attr('iso-date'),
  modificationTime                  : DS.attr('iso-date'),
  blockSize                         : DS.attr('number'),
  replication                       : DS.attr('number'),
  size                              : Ember.computed.alias('len'),

  path: function() {
    return this.get('id');
  }.property('id'),

  name: function() {
    var splitPath = this.get('path').split('/');
    return splitPath.get(splitPath.length - 1);
  }.property('path'),

  date: function() {
    return parseInt(moment(this.get('modificationTime')).format('X'));
  }.property('modificationTime')

});

==> apache-ambari-2.7.9-src.tar.gz: apache-ambari-2.7.9-src/contrib/views/files/src/main/resources/ui/app/models/file.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import DS from 'ember-data';
import Ember from 'ember';

export default DS.Model.extend({

  isDirectory                       : DS.attr('boolean'),
  readAccess                        : DS.attr('boolean'),
  writeAccess                       : DS.attr('boolean'),
  executeAccess                     : DS.attr('boolean'),
  len                               : DS.attr('number'),
  owner                             : DS.attr('string'),
  group                             : DS.attr('string'),
  permission                        : DS.attr('string'),
  accessTime                        : DS.attr('iso-date'),
  modificationTime                  : DS.attr('iso-date'),
  blockSize                         : DS.attr('number'),
  replication                       : DS.attr('number'),
  isEncrypted                       : DS.attr('boolean'),
  isErasureCoded                    : DS.attr('boolean'),
  erasureCodingPolicyName           : DS.attr('string'),
  size                              : Ember.computed.alias('len'),

  path: function() {
    return this.get('id');
  }.property('id'),

  name: function() {
    var splitPath = this.get('path').split('/');
    return splitPath.get(splitPath.length - 1);
  }.property('path'),

  date: function() {
    return parseInt(moment(this.get('modificationTime')).format('X'));
  }.property('modificationTime')

});
